#
# Copyright 2010 Andrey Churin. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import os
import sys
import datetime

from closurebuilder.util import ClosureCommand, Error, Command, validate_name
from closurebuilder.metadata import Metadata


__all__ = ['ClosureAppCommand']


class ClosureAppCommand(ClosureCommand):
    """Create a closure application"""

    summary = __doc__

    min_args = 1
    max_args = 1

    default_verbosity = 3

    group_name = 'Closure'

    parser = Command.standard_parser(simulate=True)

    parser.add_option('--path',
                      action='store',
                      dest='path',
                      default=None,
                      help='Application directory')

    def command_execute(self):
        "Main command to create client application"

        name = self.args[0]
        validate_name(name)

        meta = Metadata.get_instance()
        meta.configure();

        if os.path.exists(os.path.join(meta.closure_dir, name)):
            raise Error('Cannot create application, file or directory '
                        'exists at the specified path:\n'
                        '    "%s"'%os.path.join(meta.closure_dir, name))

        dest_dir = os.path.normpath(os.path.join(meta.closure_dir,
                                                self.options.path or name))
        if not dest_dir.startswith(meta.closure_dir):
            raise Error('Cannot create application at the specified path:\n'
                        '    "%s"'%dest_dir)

        app_file = name.rsplit('.', 1)[-1]

        meta.template_vars.update({
            'name': name,
            'file_name': app_file,
        })

        meta.copy_file('app_default_tmpl', dest_dir, app_file + '.js')

        meta.copy_file('styles_tmpl', dest_dir, app_file + '.css')
        meta.copy_file('manifest_tmpl', dest_dir, 'manifest.txt')
