#!/usr/bin/env python
#
# Closure Builder package
#
# Copyright 2010 Andrey Churin. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

f = open('README')
long_description = f.read().strip()
f.close()


setup(
  name='ClosureBuilder',
  version='0.3.4',
  long_description=long_description,
  description='The Closure Builder is a simple dependency management '
              'tool for The Closure compiler',
  license='Apache License v2',
  author='Andrey Churin',
  author_email='aachurin@gmail.com',
  install_requires=['cssutils>=0.9', 'PasteScript', 'tempita'],
  package_dir={'closurebuilder': 'closurebuilder'},
  packages=['closurebuilder'],
  package_data={'closurebuilder': [
    'templates/*_tmpl',
    'templates/licenses/*_tmpl',
    'jar/*.jar',
    'closurelibs/*']},
  #include_package_data=True,
  entry_points=
  """
  [paste.paster_command]
  help = closurebuilder.help:HelpCommand
  init = closurebuilder.closureinit:ClosureInitCommand
  create-app = closurebuilder.closureapp:ClosureAppCommand
  compile = closurebuilder.closurecompile:ClosureCompileCommand
  [console_scripts]
  closure-builder = closurebuilder.script:run
  """,

  keywords = [
      'ClosureBuilder Closure compiler javascript management',
  ],

  classifiers = [
      'Development Status :: 4 - Beta',
      'Environment :: Console',
      'Framework :: Pylons',
      'Intended Audience :: Developers',
      'Operating System :: OS Independent',
      'Programming Language :: Python',
      'Programming Language :: Java',
      'Programming Language :: JavaScript',
      'Topic :: Software Development :: Compilers',
      'Topic :: Software Development :: Build Tools',
      'License :: OSI Approved :: Apache Software License',
  ],
)
